@@ -1,4 +1,5 @@
 from miamcpdoc.main import create_server
+from miamcpdoc.splash import SPLASH
 
 def main():
     """AI SDK Documentation MCP Server."""
@@ -6,6 +7,8 @@ def main():
         {"name": "VercelAISDK", "llms_txt": "https://ai-sdk.dev/llms.txt"}
     ]
     
+    print(SPLASH)
+    print("Loading AI SDK documentation...")
     server = create_server(doc_sources)
     server.run(transport="stdio")
 
