@@ -1,4 +1,5 @@
 from miamcpdoc.main import create_server
+from miamcpdoc.splash import SPLASH
 
 def main():
     """What is LLMs Documentation MCP Server."""
@@ -6,6 +7,8 @@ def main():
         {"name": "WhatIsLLMs", "llms_txt": "https://llmstxt.org/llms.txt"}
     ]
     
+    print(SPLASH)
+    print("Loading What is LLMs documentation...")
     server = create_server(doc_sources)
     server.run(transport="stdio")
 
